#region 1. Using Statemetns
using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;

// Our own library
using XnaAssignments;
#endregion

namespace MyGame_Program
{
    /// <summary>
    ///  This is the main class. Notice this class must subclass from the XnaAssignmentBase
    /// </summary>
    public class MyGame : XnaAssignmentBase
    {
#region Program state
        // Location and size of the world
        private const float WORLD_MIN_X = 0.0f;        // lower left corner is (_0_, 0)
        private const float WORLD_MIN_Y = 0.0f;        // lower left corner is (0, _0_)
        private const float WORLD_WIDTH = 720f;        // width of the world 
        // Height is auto-calculated from the width so that the proper aspect
        // ratio is preserved

        Vector2 m_Position;     // Position of the egg

#endregion

#region Constructor & Initialization of the world
        /// <summary>
        /// This is the constructor. Notice we must call the base class's constructor
        /// by passing in the coordinate of the lower-left corner, and the width of the world.
        /// </summary>
        public MyGame()
            : base(new Vector2(WORLD_MIN_X, WORLD_MIN_Y), WORLD_WIDTH)
        {
            //  Notice:  memory allocation and initialization should be performed
            //           in InitializedWorld(). The constructor should be empty.
        }

        /// <summary>
        /// Initialize the application state
        /// </summary>
        protected override void InitializeWorld()
        {
            // allocate memory for the application
            m_Position = new Vector2();

            // initialize the Egg Position
            m_Position = 240.0f;
            m_Position.Y = 180.0f;

            XnaAssignmentBase.BackgroundColor = new Color(140, 140, 140);  // Gray-ish background
        }
#endregion

#region Update the game
        /// <summary>
        /// Update the application state. 
        /// </summary>
        protected override void UpdateWorld()
        {
            // Quits with the back button
            if (XnaAssignmentBase.GamePad.ButtonBackClicked())
                this.Exit();

            // Notice one should never draw anything in the UpdateWorld() function!
        }
#endregion

#region Draw everything to the application window
        /// <summary>
        /// Draw the application state
        /// </summary>
        protected override void DrawWorld()
        {
            // Draw the Egg
            DrawRectangle(m_Position 40 /* width */, 50 /* height */, 15.0f /*rotate */, Color.White, Color.Red,"egg");
            // DrawRectangle(m_Position, 40 /* width */, 50 /* height */, 0.0f /*rotate */, Color.White, Color.Red, null);
            EchoToTopStatus("Hey! Check out my easter egg!);

            EchoToBottomStatus("This gets ignored")
            EchoToBottomstatus("Size of the world: width:" + WorldMax.X + " height: " + WorldMax);
#endregion
    }
}
